@@ -1,3 +1,9 @@
+from __future__ import absolute_import
+
+# pre-import the big packages to avoid some warnings
+import emcee     # producing ABC warning
+import nbsphinx  # producing ABC warning
+
 from .model import *
 from .likelihood import *
 from . import posterior
@@ -5,21 +11,23 @@ from .mcmc import *
 from .prior import *
 from .utils import *
 from .report import *
-from .plot import *
 from .fitting import *
-import os 
-import sys
+from .plot import *
+
 import warnings
+warnings.filterwarnings("ignore")
 
-warnings.simplefilter('once')
 
 def _custom_warningfmt(msg, *a, **b):
     return "WARNING:", str(msg) + '\n'
 
-__all__=['model', 'likelihood', 'posterior', 'mcmc', 'prior', 'utils',
+
+__all__ = ['model', 'likelihood', 'posterior', 'mcmc', 'prior', 'utils',
          'fitting', 'report', 'cli', 'driver', 'gp']
 
-__version__ = '1.1.11'
+__version__ = '1.3.5'
+__spec__ = __name__
+__package__ = __path__[0]
 
 MODULEDIR, filename = os.path.split(__file__)
 DATADIR = os.path.join(sys.prefix, 'radvel_example_data')
@@ -37,6 +45,7 @@ if not os.path.isdir(DATADIR):
 # tell python how to pickle methods and fucntions; necessary for running MCMC in multi-
 #  threaded mode.
 
+
 def _pickle_method(method):
     func_name = method.im_func.__name__
     obj = method.im_self
@@ -57,4 +66,5 @@ def _unpickle_method(func_name, obj, cls):
 
 if sys.version_info[0] < 3:
     import copy_reg
+    import types
     copy_reg.pickle(types.MethodType, _pickle_method, _unpickle_method)
